@@ -15,8 +15,9 @@ not differ from the binary case.
 from collections import Counter
 
 from sklearn.datasets import load_iris
-from sklearn.svm import LinearSVC
+from sklearn.linear_model import LogisticRegression
 from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import StandardScaler
 
 from imblearn.datasets import make_imbalance
 from imblearn.under_sampling import NearMiss
@@ -29,19 +30,22 @@ RANDOM_STATE = 42
 
 # Create a folder to fetch the dataset
 iris = load_iris()
-X, y = make_imbalance(iris.data, iris.target,
-                      sampling_strategy={0: 25, 1: 50, 2: 50},
-                      random_state=RANDOM_STATE)
+X, y = make_imbalance(
+    iris.data,
+    iris.target,
+    sampling_strategy={0: 25, 1: 50, 2: 50},
+    random_state=RANDOM_STATE,
+)
 
-X_train, X_test, y_train, y_test = train_test_split(
-    X, y, random_state=RANDOM_STATE)
+X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=RANDOM_STATE)
 
-print('Training target statistics: {}'.format(Counter(y_train)))
-print('Testing target statistics: {}'.format(Counter(y_test)))
+print(f"Training target statistics: {Counter(y_train)}")
+print(f"Testing target statistics: {Counter(y_test)}")
 
 # Create a pipeline
-pipeline = make_pipeline(NearMiss(version=2),
-                         LinearSVC(random_state=RANDOM_STATE))
+pipeline = make_pipeline(
+    NearMiss(version=2), StandardScaler(), LogisticRegression(random_state=RANDOM_STATE)
+)
 pipeline.fit(X_train, y_train)
 
 # Classify and report the results
