@@ -37,18 +37,36 @@ class SMOTETomek(BaseSampler):
 
     {random_state}
 
-    smote : object, default=None
-        The :class:`imblearn.over_sampling.SMOTE` object to use. If not given,
-        a :class:`imblearn.over_sampling.SMOTE` object with default parameters
+    smote : sampler object, default=None
+        The :class:`~imblearn.over_sampling.SMOTE` object to use. If not given,
+        a :class:`~imblearn.over_sampling.SMOTE` object with default parameters
         will be given.
 
-    tomek : object, default=None
-        The :class:`imblearn.under_sampling.TomekLinks` object to use. If not
-        given, a :class:`imblearn.under_sampling.TomekLinks` object with
+    tomek : sampler object, default=None
+        The :class:`~imblearn.under_sampling.TomekLinks` object to use. If not
+        given, a :class:`~imblearn.under_sampling.TomekLinks` object with
         sampling strategy='all' will be given.
 
     {n_jobs}
 
+    Attributes
+    ----------
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    smote_ : sampler object
+        The validated :class:`~imblearn.over_sampling.SMOTE` instance.
+
+    tomek_ : sampler object
+        The validated :class:`~imblearn.under_sampling.TomekLinks` instance.
+
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     SMOTEENN : Over-sample using SMOTE followed by under-sampling using Edited
@@ -111,8 +129,8 @@ SMOTETomek # doctest: +NORMALIZE_WHITESPACE
                 self.smote_ = clone(self.smote)
             else:
                 raise ValueError(
-                    "smote needs to be a SMOTE object."
-                    "Got {} instead.".format(type(self.smote))
+                    f"smote needs to be a SMOTE object."
+                    f"Got {type(self.smote)} instead."
                 )
         # Otherwise create a default SMOTE
         else:
@@ -127,14 +145,12 @@ SMOTETomek # doctest: +NORMALIZE_WHITESPACE
                 self.tomek_ = clone(self.tomek)
             else:
                 raise ValueError(
-                    "tomek needs to be a TomekLinks object."
-                    "Got {} instead.".format(type(self.tomek))
+                    f"tomek needs to be a TomekLinks object."
+                    f"Got {type(self.tomek)} instead."
                 )
         # Otherwise create a default TomekLinks
         else:
-            self.tomek_ = TomekLinks(
-                sampling_strategy="all", n_jobs=self.n_jobs
-            )
+            self.tomek_ = TomekLinks(sampling_strategy="all", n_jobs=self.n_jobs)
 
     def _fit_resample(self, X, y):
         self._validate_estimator()
