@@ -16,8 +16,7 @@ from ..utils._validation import _deprecate_positional_args
 def make_imbalance(
     X, y, *, sampling_strategy=None, random_state=None, verbose=False, **kwargs
 ):
-    """Turns a dataset into an imbalanced dataset with a specific sampling
-    strategy.
+    """Turn a dataset into an imbalanced dataset with a specific sampling strategy.
 
     A simple toy dataset to visualize clustering and classification
     algorithms.
@@ -26,13 +25,13 @@ def make_imbalance(
 
     Parameters
     ----------
-    X : {array-like, dataframe}, shape (n_samples, n_features)
+    X : {array-like, dataframe} of shape (n_samples, n_features)
         Matrix containing the data to be imbalanced.
 
-    y : ndarray, shape (n_samples, )
+    y : ndarray of shape (n_samples,)
         Corresponding label for each sample in X.
 
-    sampling_strategy : dict, or callable,
+    sampling_strategy : dict or callable,
         Ratio to use for resampling the data set.
 
         - When ``dict``, the keys correspond to the targeted classes. The
@@ -43,33 +42,33 @@ def make_imbalance(
           correspond to the targeted classes. The values correspond to the
           desired number of samples for each class.
 
-    random_state : int, RandomState instance or None, optional (default=None)
+    random_state : int, RandomState instance or None, default=None
         If int, random_state is the seed used by the random number generator;
         If RandomState instance, random_state is the random number generator;
         If None, the random number generator is the RandomState instance used
         by np.random.
 
-    verbose : bool, optional (default=False)
+    verbose : bool, default=False
         Show information regarding the sampling.
 
-    kwargs : dict, optional
+    **kwargs : dict
         Dictionary of additional keyword arguments to pass to
         ``sampling_strategy``.
 
     Returns
     -------
-    X_resampled : {ndarray, dataframe}, shape (n_samples_new, n_features)
+    X_resampled : {ndarray, dataframe} of shape (n_samples_new, n_features)
         The array containing the imbalanced data.
 
-    y_resampled : ndarray, shape (n_samples_new)
-        The corresponding label of `X_resampled`
+    y_resampled : ndarray of shape (n_samples_new)
+        The corresponding label of `X_resampled`.
 
     Notes
     -----
     See
     :ref:`sphx_glr_auto_examples_applications_plot_multi_class_under_sampling.py`,
     :ref:`sphx_glr_auto_examples_datasets_plot_make_imbalance.py`, and
-    :ref:`sphx_glr_auto_examples_plot_sampling_strategy_usage.py`.
+    :ref:`sphx_glr_auto_examples_api_plot_sampling_strategy_usage.py`.
 
     Examples
     --------
@@ -79,14 +78,13 @@ def make_imbalance(
 
     >>> data = load_iris()
     >>> X, y = data.data, data.target
-    >>> print('Distribution before imbalancing: {}'.format(Counter(y)))
+    >>> print(f'Distribution before imbalancing: {Counter(y)}')
     Distribution before imbalancing: Counter({0: 50, 1: 50, 2: 50})
     >>> X_res, y_res = make_imbalance(X, y,
     ...                               sampling_strategy={0: 10, 1: 20, 2: 30},
     ...                               random_state=42)
-    >>> print('Distribution after imbalancing: {}'.format(Counter(y_res)))
+    >>> print(f'Distribution after imbalancing: {Counter(y_res)}')
     Distribution after imbalancing: Counter({2: 30, 1: 20, 0: 10})
-
     """
     target_stats = Counter(y)
     # restrict ratio to be a dict or a callable
@@ -96,17 +94,13 @@ def make_imbalance(
         )
     else:
         raise ValueError(
-            "'sampling_strategy' has to be a dictionary or a "
-            "function returning a dictionary. Got {} instead.".format(
-                type(sampling_strategy)
-            )
+            f"'sampling_strategy' has to be a dictionary or a "
+            f"function returning a dictionary. Got {type(sampling_strategy)} "
+            f"instead."
         )
 
     if verbose:
-        print(
-            "The original target distribution in the dataset is: %s",
-            target_stats,
-        )
+        print(f"The original target distribution in the dataset is: {target_stats}")
     rus = RandomUnderSampler(
         sampling_strategy=sampling_strategy_,
         replacement=False,
@@ -114,6 +108,6 @@ def make_imbalance(
     )
     X_resampled, y_resampled = rus.fit_resample(X, y)
     if verbose:
-        print("Make the dataset imbalanced: %s", Counter(y_resampled))
+        print(f"Make the dataset imbalanced: {Counter(y_resampled)}")
 
     return X_resampled, y_resampled
