@@ -3,10 +3,12 @@
 #          Christos Aridas
 # License: MIT
 
+from collections import Counter
+
 import numpy as np
 import pytest
 
-from sklearn.datasets import load_iris, make_hastie_10_2
+from sklearn.datasets import load_iris, make_hastie_10_2, make_classification
 from sklearn.model_selection import (
     GridSearchCV,
     ParameterGrid,
@@ -22,15 +24,39 @@ from sklearn.utils._testing import assert_array_equal
 from sklearn.utils._testing import assert_array_almost_equal
 from sklearn.utils._testing import assert_allclose
 
+from imblearn import FunctionSampler
 from imblearn.datasets import make_imbalance
 from imblearn.ensemble import BalancedBaggingClassifier
+from imblearn.over_sampling import RandomOverSampler, SMOTE
 from imblearn.pipeline import make_pipeline
-from imblearn.under_sampling import RandomUnderSampler
+from imblearn.under_sampling import ClusterCentroids, RandomUnderSampler
 
 iris = load_iris()
 
 
-def test_balanced_bagging_classifier():
+@pytest.mark.parametrize(
+    "base_estimator",
+    [
+        None,
+        DummyClassifier(strategy="prior"),
+        Perceptron(max_iter=1000, tol=1e-3),
+        DecisionTreeClassifier(),
+        KNeighborsClassifier(),
+        SVC(gamma="scale"),
+    ],
+)
+@pytest.mark.parametrize(
+    "params",
+    ParameterGrid(
+        {
+            "max_samples": [0.5, 1.0],
+            "max_features": [1, 2, 4],
+            "bootstrap": [True, False],
+            "bootstrap_features": [True, False],
+        }
+    ),
+)
+def test_balanced_bagging_classifier(base_estimator, params):
     # Check classification for various parameter settings.
     X, y = make_imbalance(
         iris.data,
@@ -39,27 +65,10 @@ def test_balanced_bagging_classifier():
         random_state=0,
     )
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
-    grid = ParameterGrid(
-        {
-            "max_samples": [0.5, 1.0],
-            "max_features": [1, 2, 4],
-            "bootstrap": [True, False],
-            "bootstrap_features": [True, False],
-        }
-    )
 
-    for base_estimator in [
-        None,
-        DummyClassifier(strategy="prior"),
-        Perceptron(max_iter=1000, tol=1e-3),
-        DecisionTreeClassifier(),
-        KNeighborsClassifier(),
-        SVC(gamma="scale"),
-    ]:
-        for params in grid:
-            BalancedBaggingClassifier(
-                base_estimator=base_estimator, random_state=0, **params
-            ).fit(X_train, y_train).predict(X_test)
+    BalancedBaggingClassifier(
+        base_estimator=base_estimator, random_state=0, **params
+    ).fit(X_train, y_train).predict(X_test)
 
 
 def test_bootstrap_samples():
@@ -85,9 +94,7 @@ def test_bootstrap_samples():
         random_state=0,
     ).fit(X_train, y_train)
 
-    assert ensemble.score(X_train, y_train) == base_estimator.score(
-        X_train, y_train
-    )
+    assert ensemble.score(X_train, y_train) == base_estimator.score(X_train, y_train)
 
     # with bootstrap, trees are no longer perfect on the training set
     ensemble = BalancedBaggingClassifier(
@@ -97,9 +104,7 @@ def test_bootstrap_samples():
         random_state=0,
     ).fit(X_train, y_train)
 
-    assert ensemble.score(X_train, y_train) < base_estimator.score(
-        X_train, y_train
-    )
+    assert ensemble.score(X_train, y_train) < base_estimator.score(X_train, y_train)
 
 
 def test_bootstrap_features():
@@ -130,8 +135,7 @@ def test_bootstrap_features():
     ).fit(X_train, y_train)
 
     unique_features = [
-        np.unique(features).shape[0]
-        for features in ensemble.estimators_features_
+        np.unique(features).shape[0] for features in ensemble.estimators_features_
     ]
     assert np.median(unique_features) < X.shape[1]
 
@@ -164,9 +168,7 @@ def test_probability():
 
         # Degenerate case, where some classes are missing
         ensemble = BalancedBaggingClassifier(
-            base_estimator=LogisticRegression(
-                solver="lbfgs", multi_class="auto"
-            ),
+            base_estimator=LogisticRegression(solver="lbfgs", multi_class="auto"),
             random_state=0,
             max_samples=5,
         )
@@ -237,56 +239,42 @@ def test_single_estimator():
     ).fit(X_train, y_train)
 
     clf2 = make_pipeline(
-        RandomUnderSampler(
-            random_state=clf1.estimators_[0].steps[0][1].random_state
-        ),
+        RandomUnderSampler(random_state=clf1.estimators_[0].steps[0][1].random_state),
         KNeighborsClassifier(),
     ).fit(X_train, y_train)
 
     assert_array_equal(clf1.predict(X_test), clf2.predict(X_test))
 
 
-def test_error():
+@pytest.mark.parametrize(
+    "params",
+    [
+        {"n_estimators": 1.5},
+        {"n_estimators": -1},
+        {"max_samples": -1},
+        {"max_samples": 0.0},
+        {"max_samples": 2.0},
+        {"max_samples": 1000},
+        {"max_samples": "foobar"},
+        {"max_features": -1},
+        {"max_features": 0.0},
+        {"max_features": 2.0},
+        {"max_features": 5},
+        {"max_features": "foobar"},
+    ],
+)
+def test_balanced_bagging_classifier_error(params):
     # Test that it gives proper exception on deficient input.
     X, y = make_imbalance(
         iris.data, iris.target, sampling_strategy={0: 20, 1: 25, 2: 50}
     )
     base = DecisionTreeClassifier()
-
-    # Test n_estimators
+    clf = BalancedBaggingClassifier(base_estimator=base, **params)
     with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, n_estimators=1.5).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, n_estimators=-1).fit(X, y)
-
-    # Test max_samples
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_samples=-1).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_samples=0.0).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_samples=2.0).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_samples=1000).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_samples="foobar").fit(X, y)
-
-    # Test max_features
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_features=-1).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_features=0.0).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_features=2.0).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_features=5).fit(X, y)
-    with pytest.raises(ValueError):
-        BalancedBaggingClassifier(base, max_features="foobar").fit(X, y)
+        clf.fit(X, y)
 
     # Test support of decision_function
-    assert not (
-        hasattr(BalancedBaggingClassifier(base).fit(X, y), "decision_function")
-    )
+    assert not (hasattr(BalancedBaggingClassifier(base).fit(X, y), "decision_function"))
 
 
 def test_gridsearch():
@@ -320,17 +308,13 @@ def test_base_estimator():
         X_train, y_train
     )
 
-    assert isinstance(
-        ensemble.base_estimator_.steps[-1][1], DecisionTreeClassifier
-    )
+    assert isinstance(ensemble.base_estimator_.steps[-1][1], DecisionTreeClassifier)
 
     ensemble = BalancedBaggingClassifier(
         DecisionTreeClassifier(), n_jobs=3, random_state=0
     ).fit(X_train, y_train)
 
-    assert isinstance(
-        ensemble.base_estimator_.steps[-1][1], DecisionTreeClassifier
-    )
+    assert isinstance(ensemble.base_estimator_.steps[-1][1], DecisionTreeClassifier)
 
     ensemble = BalancedBaggingClassifier(
         Perceptron(max_iter=1000, tol=1e-3), n_jobs=3, random_state=0
@@ -396,9 +380,7 @@ def test_warm_start_equal_n_estimators():
     X, y = make_hastie_10_2(n_samples=20, random_state=1)
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=43)
 
-    clf = BalancedBaggingClassifier(
-        n_estimators=5, warm_start=True, random_state=83
-    )
+    clf = BalancedBaggingClassifier(n_estimators=5, warm_start=True, random_state=83)
     clf.fit(X_train, y_train)
 
     y_pred = clf.predict(X_test)
@@ -437,9 +419,7 @@ def test_warm_start_equivalence():
 def test_warm_start_with_oob_score_fails():
     # Check using oob_score and warm_start simultaneously fails
     X, y = make_hastie_10_2(n_samples=20, random_state=1)
-    clf = BalancedBaggingClassifier(
-        n_estimators=5, warm_start=True, oob_score=True
-    )
+    clf = BalancedBaggingClassifier(n_estimators=5, warm_start=True, oob_score=True)
     with pytest.raises(ValueError):
         clf.fit(X, y)
 
@@ -527,3 +507,100 @@ def test_max_samples_consistency():
     )
     bagging.fit(X, y)
     assert bagging._max_samples == max_samples
+
+
+class CountDecisionTreeClassifier(DecisionTreeClassifier):
+    """DecisionTreeClassifier that will memorize the number of samples seen
+    at fit."""
+
+    def fit(self, X, y, sample_weight=None):
+        self.class_counts_ = Counter(y)
+        return super().fit(X, y, sample_weight=sample_weight)
+
+
+@pytest.mark.parametrize(
+    "sampler, n_samples_bootstrap",
+    [
+        (None, 15),
+        (RandomUnderSampler(), 15),  # under-sampling with sample_indices_
+        (ClusterCentroids(), 15),  # under-sampling without sample_indices_
+        (RandomOverSampler(), 40),  # over-sampling with sample_indices_
+        (SMOTE(), 40),  # over-sampling without sample_indices_
+    ],
+)
+def test_balanced_bagging_classifier_samplers(sampler, n_samples_bootstrap):
+    # check that we can pass any kind of sampler to a bagging classifier
+    X, y = make_imbalance(
+        iris.data,
+        iris.target,
+        sampling_strategy={0: 20, 1: 25, 2: 50},
+        random_state=0,
+    )
+    X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
+    clf = BalancedBaggingClassifier(
+        base_estimator=CountDecisionTreeClassifier(),
+        n_estimators=2,
+        sampler=sampler,
+        random_state=0,
+    )
+    clf.fit(X_train, y_train)
+    clf.predict(X_test)
+
+    # check that we have balanced class with the right counts of class
+    # sample depending on the sampling strategy
+    assert_array_equal(
+        list(clf.estimators_[0][-1].class_counts_.values()), n_samples_bootstrap
+    )
+
+
+@pytest.mark.parametrize("replace", [True, False])
+def test_balanced_bagging_classifier_with_function_sampler(replace):
+    # check that we can provide a FunctionSampler in BalancedBaggingClassifier
+    X, y = make_classification(
+        n_samples=1_000,
+        n_features=10,
+        n_classes=2,
+        weights=[0.3, 0.7],
+        random_state=0,
+    )
+
+    def roughly_balanced_bagging(X, y, replace=False):
+        """Implementation of Roughly Balanced Bagging for binary problem."""
+        # find the minority and majority classes
+        class_counts = Counter(y)
+        majority_class = max(class_counts, key=class_counts.get)
+        minority_class = min(class_counts, key=class_counts.get)
+
+        # compute the number of sample to draw from the majority class using
+        # a negative binomial distribution
+        n_minority_class = class_counts[minority_class]
+        n_majority_resampled = np.random.negative_binomial(n=n_minority_class, p=0.5)
+
+        # draw randomly with or without replacement
+        majority_indices = np.random.choice(
+            np.flatnonzero(y == majority_class),
+            size=n_majority_resampled,
+            replace=replace,
+        )
+        minority_indices = np.random.choice(
+            np.flatnonzero(y == minority_class),
+            size=n_minority_class,
+            replace=replace,
+        )
+        indices = np.hstack([majority_indices, minority_indices])
+
+        return X[indices], y[indices]
+
+    # Roughly Balanced Bagging
+    rbb = BalancedBaggingClassifier(
+        base_estimator=CountDecisionTreeClassifier(),
+        n_estimators=2,
+        sampler=FunctionSampler(
+            func=roughly_balanced_bagging, kw_args={"replace": replace}
+        ),
+    )
+    rbb.fit(X, y)
+
+    for estimator in rbb.estimators_:
+        class_counts = estimator[-1].class_counts_
+        assert (class_counts[0] / class_counts[1]) > 0.8
