@@ -64,9 +64,7 @@ def test_easy_ensemble_classifier(n_estimators, base_estimator):
     eec.fit(X_train, y_train).score(X_test, y_test)
     assert len(eec.estimators_) == n_estimators
     for est in eec.estimators_:
-        assert (
-            len(est.named_steps["classifier"]) == base_estimator.n_estimators
-        )
+        assert len(est.named_steps["classifier"]) == base_estimator.n_estimators
     # test the different prediction function
     eec.predict(X_test)
     eec.predict_proba(X_test)
@@ -88,17 +86,13 @@ def test_base_estimator():
         X_train, y_train
     )
 
-    assert isinstance(
-        ensemble.base_estimator_.steps[-1][1], AdaBoostClassifier
-    )
+    assert isinstance(ensemble.base_estimator_.steps[-1][1], AdaBoostClassifier)
 
     ensemble = EasyEnsembleClassifier(
         2, AdaBoostClassifier(), n_jobs=-1, random_state=0
     ).fit(X_train, y_train)
 
-    assert isinstance(
-        ensemble.base_estimator_.steps[-1][1], AdaBoostClassifier
-    )
+    assert isinstance(ensemble.base_estimator_.steps[-1][1], AdaBoostClassifier)
 
 
 def test_bagging_with_pipeline():
@@ -158,9 +152,7 @@ def test_warm_start_equal_n_estimators():
     X, y = make_hastie_10_2(n_samples=20, random_state=1)
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=43)
 
-    clf = EasyEnsembleClassifier(
-        n_estimators=5, warm_start=True, random_state=83
-    )
+    clf = EasyEnsembleClassifier(n_estimators=5, warm_start=True, random_state=83)
     clf.fit(X_train, y_train)
 
     y_pred = clf.predict(X_test)
@@ -179,17 +171,13 @@ def test_warm_start_equivalence():
     X, y = make_hastie_10_2(n_samples=20, random_state=1)
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=43)
 
-    clf_ws = EasyEnsembleClassifier(
-        n_estimators=5, warm_start=True, random_state=3141
-    )
+    clf_ws = EasyEnsembleClassifier(n_estimators=5, warm_start=True, random_state=3141)
     clf_ws.fit(X_train, y_train)
     clf_ws.set_params(n_estimators=10)
     clf_ws.fit(X_train, y_train)
     y1 = clf_ws.predict(X_test)
 
-    clf = EasyEnsembleClassifier(
-        n_estimators=10, warm_start=False, random_state=3141
-    )
+    clf = EasyEnsembleClassifier(n_estimators=10, warm_start=False, random_state=3141)
     clf.fit(X_train, y_train)
     y2 = clf.predict(X_test)
 
@@ -224,9 +212,7 @@ def test_easy_ensemble_classifier_single_estimator():
     )
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
 
-    clf1 = EasyEnsembleClassifier(n_estimators=1, random_state=0).fit(
-        X_train, y_train
-    )
+    clf1 = EasyEnsembleClassifier(n_estimators=1, random_state=0).fit(X_train, y_train)
     clf2 = make_pipeline(
         RandomUnderSampler(random_state=0), AdaBoostClassifier(random_state=0)
     ).fit(X_train, y_train)
