@@ -26,15 +26,19 @@ def imbalanced_dataset():
 
 
 @pytest.mark.parametrize(
-    "boosting_params, err_msg",
+    "boosting_params, err_type, err_msg",
     [
-        ({"n_estimators": "whatever"}, "n_estimators must be an integer"),
-        ({"n_estimators": -100}, "n_estimators must be greater than zero"),
+        (
+            {"n_estimators": "whatever"},
+            TypeError,
+            "n_estimators must be an instance of int, not str.",
+        ),
+        ({"n_estimators": -100}, ValueError, "n_estimators == -100, must be >= 1."),
     ],
 )
-def test_rusboost_error(imbalanced_dataset, boosting_params, err_msg):
+def test_rusboost_error(imbalanced_dataset, boosting_params, err_type, err_msg):
     rusboost = RUSBoostClassifier(**boosting_params)
-    with pytest.raises(ValueError, match=err_msg):
+    with pytest.raises(err_type, match=err_msg):
         rusboost.fit(*imbalanced_dataset)
 
 
