@@ -1,6 +1,9 @@
 """Implement generators for ``keras`` which will balance the data."""
 
 
+# This is a trick to avoid an error during tests collection with pytest. We
+# avoid the error when importing the package raise the error at the moment of
+# creating the instance.
 # This is a trick to avoid an error during tests collection with pytest. We
 # avoid the error when importing the package raise the error at the moment of
 # creating the instance.
@@ -8,16 +11,16 @@ def import_keras():
     """Try to import keras from keras and tensorflow.
 
     This is possible to import the sequence from keras or tensorflow.
-    Keras is not ducktyping ``Sequence`` before 2.3 and we need import from
-    all possible library to ensure that the ``isinstance(...)`` is not going
-    to fail. This function can be modified when we support Keras 2.3.
     """
 
     def import_from_keras():
         try:
-            import keras
+            import keras  # noqa
 
-            return (keras.utils.Sequence,), True
+            if hasattr(keras.utils, "Sequence"):
+                return (keras.utils.Sequence,), True
+            else:
+                return (keras.utils.data_utils.Sequence,), True
         except ImportError:
             return tuple(), False
 
@@ -25,7 +28,10 @@ def import_keras():
         try:
             from tensorflow import keras
 
-            return (keras.utils.Sequence,), True
+            if hasattr(keras.utils, "Sequence"):
+                return (keras.utils.Sequence,), True
+            else:
+                return (keras.utils.data_utils.Sequence,), True
         except ImportError:
             return tuple(), False
 
@@ -33,7 +39,10 @@ def import_keras():
     ParentClassTensorflow, has_keras_tf = import_from_tensforflow()
     has_keras = has_keras_k or has_keras_tf
     if has_keras:
-        ParentClass = ParentClassKeras + ParentClassTensorflow
+        if has_keras_k:
+            ParentClass = ParentClassKeras
+        else:
+            ParentClass = ParentClassTensorflow
     else:
         ParentClass = (object,)
     return ParentClass, has_keras
@@ -54,39 +63,41 @@ from ..tensorflow import balanced_batch_generator as tf_bbg  # noqa
 from ..utils._validation import _deprecate_positional_args  # noqa
 
 
-class BalancedBatchGenerator(*ParentClass):
+class BalancedBatchGenerator(*ParentClass):  # type: ignore
     """Create balanced batches when training a keras model.
 
-    Create a keras ``Sequence`` which is given to ``fit_generator``. The
+    Create a keras ``Sequence`` which is given to ``fit``. The
     sampler defines the sampling strategy used to balance the dataset ahead of
     creating the batch. The sampler should have an attribute
     ``sample_indices_``.
 
+    .. versionadded:: 0.4
+
     Parameters
     ----------
-    X : ndarray, shape (n_samples, n_features)
+    X : ndarray of shape (n_samples, n_features)
         Original imbalanced dataset.
 
-    y : ndarray, shape (n_samples,) or (n_samples, n_classes)
+    y : ndarray of shape (n_samples,) or (n_samples, n_classes)
         Associated targets.
 
-    sample_weight : ndarray, shape (n_samples,)
+    sample_weight : ndarray of shape (n_samples,)
         Sample weight.
 
-    sampler : object or None, optional (default=RandomUnderSampler)
+    sampler : sampler object, default=None
         A sampler instance which has an attribute ``sample_indices_``.
         By default, the sampler used is a
-        :class:`imblearn.under_sampling.RandomUnderSampler`.
+        :class:`~imblearn.under_sampling.RandomUnderSampler`.
 
-    batch_size : int, optional (default=32)
+    batch_size : int, default=32
         Number of samples per gradient update.
 
-    keep_sparse : bool, optional (default=False)
+    keep_sparse : bool, default=False
         Either or not to conserve or not the sparsity of the input (i.e. ``X``,
         ``y``, ``sample_weight``). By default, the returned batches will be
         dense.
 
-    random_state : int, RandomState instance or None, optional (default=None)
+    random_state : int, RandomState instance or None, default=None
         Control the randomization of the algorithm:
 
         - If int, ``random_state`` is the seed used by the random number
@@ -98,10 +109,10 @@ class BalancedBatchGenerator(*ParentClass):
 
     Attributes
     ----------
-    sampler_ : object
+    sampler_ : sampler object
         The sampler used to balance the dataset.
 
-    indices_ : ndarray, shape (n_samples, n_features)
+    indices_ : ndarray of shape (n_samples, n_features)
         The indices of the samples selected during sampling.
 
     Examples
@@ -111,21 +122,22 @@ class BalancedBatchGenerator(*ParentClass):
     >>> from imblearn.datasets import make_imbalance
     >>> class_dict = dict()
     >>> class_dict[0] = 30; class_dict[1] = 50; class_dict[2] = 40
-    >>> X, y = make_imbalance(iris.data, iris.target, class_dict)
-    >>> import keras
-    >>> y = keras.utils.to_categorical(y, 3)
-    >>> model = keras.models.Sequential()
-    >>> model.add(keras.layers.Dense(y.shape[1], input_dim=X.shape[1],
-    ...                              activation='softmax'))
+    >>> X, y = make_imbalance(iris.data, iris.target, sampling_strategy=class_dict)
+    >>> import tensorflow
+    >>> y = tensorflow.keras.utils.to_categorical(y, 3)
+    >>> model = tensorflow.keras.models.Sequential()
+    >>> model.add(
+    ...     tensorflow.keras.layers.Dense(
+    ...         y.shape[1], input_dim=X.shape[1], activation='softmax'
+    ...     )
+    ... )
     >>> model.compile(optimizer='sgd', loss='categorical_crossentropy',
     ...               metrics=['accuracy'])
     >>> from imblearn.keras import BalancedBatchGenerator
     >>> from imblearn.under_sampling import NearMiss
     >>> training_generator = BalancedBatchGenerator(
     ...     X, y, sampler=NearMiss(), batch_size=10, random_state=42)
-    >>> callback_history = model.fit_generator(generator=training_generator,
-    ...                                        epochs=10, verbose=0)
-
+    >>> callback_history = model.fit(training_generator, epochs=10, verbose=0)
     """
 
     # flag for keras sequence duck-typing
@@ -162,9 +174,7 @@ class BalancedBatchGenerator(*ParentClass):
             self.sampler_ = clone(self.sampler)
         self.sampler_.fit_resample(self.X, self.y)
         if not hasattr(self.sampler_, "sample_indices_"):
-            raise ValueError(
-                "'sampler' needs to have an attribute " "'sample_indices_'."
-            )
+            raise ValueError("'sampler' needs to have an attribute 'sample_indices_'.")
         self.indices_ = self.sampler_.sample_indices_
         # shuffle the indices since the sampler are packing them by class
         random_state.shuffle(self.indices_)
@@ -175,24 +185,18 @@ class BalancedBatchGenerator(*ParentClass):
     def __getitem__(self, index):
         X_resampled = _safe_indexing(
             self.X,
-            self.indices_[
-                index * self.batch_size:(index + 1) * self.batch_size
-            ],
+            self.indices_[index * self.batch_size : (index + 1) * self.batch_size],
         )
         y_resampled = _safe_indexing(
             self.y,
-            self.indices_[
-                index * self.batch_size:(index + 1) * self.batch_size
-            ],
+            self.indices_[index * self.batch_size : (index + 1) * self.batch_size],
         )
         if issparse(X_resampled) and not self.keep_sparse:
             X_resampled = X_resampled.toarray()
         if self.sample_weight is not None:
             sample_weight_resampled = _safe_indexing(
                 self.sample_weight,
-                self.indices_[
-                    index * self.batch_size:(index + 1) * self.batch_size
-                ],
+                self.indices_[index * self.batch_size : (index + 1) * self.batch_size],
             )
 
         if self.sample_weight is None:
@@ -216,30 +220,30 @@ def balanced_batch_generator(
     """Create a balanced batch generator to train keras model.
 
     Returns a generator --- as well as the number of step per epoch --- which
-    is given to ``fit_generator``. The sampler defines the sampling strategy
+    is given to ``fit``. The sampler defines the sampling strategy
     used to balance the dataset ahead of creating the batch. The sampler should
     have an attribute ``sample_indices_``.
 
     Parameters
     ----------
-    X : ndarray, shape (n_samples, n_features)
+    X : ndarray of shape (n_samples, n_features)
         Original imbalanced dataset.
 
-    y : ndarray, shape (n_samples,) or (n_samples, n_classes)
+    y : ndarray of shape (n_samples,) or (n_samples, n_classes)
         Associated targets.
 
-    sample_weight : ndarray, shape (n_samples,)
+    sample_weight : ndarray of shape (n_samples,), default=None
         Sample weight.
 
-    sampler : object or None, optional (default=RandomUnderSampler)
+    sampler : sampler object, default=None
         A sampler instance which has an attribute ``sample_indices_``.
         By default, the sampler used is a
-        :class:`imblearn.under_sampling.RandomUnderSampler`.
+        :class:`~imblearn.under_sampling.RandomUnderSampler`.
 
-    batch_size : int, optional (default=32)
+    batch_size : int, default=32
         Number of samples per gradient update.
 
-    keep_sparse : bool, optional (default=False)
+    keep_sparse : bool, default=False
         Either or not to conserve or not the sparsity of the input (i.e. ``X``,
         ``y``, ``sample_weight``). By default, the returned batches will be
         dense.
@@ -264,22 +268,24 @@ def balanced_batch_generator(
     >>> class_dict = dict()
     >>> class_dict[0] = 30; class_dict[1] = 50; class_dict[2] = 40
     >>> from imblearn.datasets import make_imbalance
-    >>> X, y = make_imbalance(X, y, class_dict)
-    >>> import keras
-    >>> y = keras.utils.to_categorical(y, 3)
-    >>> model = keras.models.Sequential()
-    >>> model.add(keras.layers.Dense(y.shape[1], input_dim=X.shape[1],
-    ...                              activation='softmax'))
+    >>> X, y = make_imbalance(X, y, sampling_strategy=class_dict)
+    >>> import tensorflow
+    >>> y = tensorflow.keras.utils.to_categorical(y, 3)
+    >>> model = tensorflow.keras.models.Sequential()
+    >>> model.add(
+    ...     tensorflow.keras.layers.Dense(
+    ...         y.shape[1], input_dim=X.shape[1], activation='softmax'
+    ...     )
+    ... )
     >>> model.compile(optimizer='sgd', loss='categorical_crossentropy',
     ...               metrics=['accuracy'])
     >>> from imblearn.keras import balanced_batch_generator
     >>> from imblearn.under_sampling import NearMiss
     >>> training_generator, steps_per_epoch = balanced_batch_generator(
     ...     X, y, sampler=NearMiss(), batch_size=10, random_state=42)
-    >>> callback_history = model.fit_generator(generator=training_generator,
-    ...                                        steps_per_epoch=steps_per_epoch,
-    ...                                        epochs=10, verbose=0)
-
+    >>> callback_history = model.fit(training_generator,
+    ...                              steps_per_epoch=steps_per_epoch,
+    ...                              epochs=10, verbose=0)
     """
 
     return tf_bbg(
