@@ -26,31 +26,33 @@ def balanced_batch_generator(
 ):
     """Create a balanced batch generator to train tensorflow model.
 
-    Returns a generator --- as well as the number of step per epoch --- which
-    is given to ``fit_generator``. The sampler defines the sampling strategy
+    Returns a generator --- as well as the number of step per epoch --- to
+    iterate to get the mini-batches. The sampler defines the sampling strategy
     used to balance the dataset ahead of creating the batch. The sampler should
     have an attribute ``sample_indices_``.
 
+    .. versionadded:: 0.4
+
     Parameters
     ----------
-    X : ndarray, shape (n_samples, n_features)
+    X : ndarray of shape (n_samples, n_features)
         Original imbalanced dataset.
 
-    y : ndarray, shape (n_samples,) or (n_samples, n_classes)
+    y : ndarray of shape (n_samples,) or (n_samples, n_classes)
         Associated targets.
 
-    sample_weight : ndarray, shape (n_samples,)
+    sample_weight : ndarray of shape (n_samples,), default=None
         Sample weight.
 
-    sampler : object or None, optional (default=RandomUnderSampler)
+    sampler : sampler object, default=None
         A sampler instance which has an attribute ``sample_indices_``.
         By default, the sampler used is a
-        :class:`imblearn.under_sampling.RandomUnderSampler`.
+        :class:`~imblearn.under_sampling.RandomUnderSampler`.
 
-    batch_size : int, optional (default=32)
+    batch_size : int, default=32
         Number of samples per gradient update.
 
-    keep_sparse : bool, optional (default=False)
+    keep_sparse : bool, default=False
         Either or not to conserve or not the sparsity of the input ``X``. By
         default, the returned batches will be dense.
 
@@ -64,7 +66,6 @@ def balanced_batch_generator(
 
     steps_per_epoch : int
         The number of samples per epoch.
-
     """
 
     random_state = check_random_state(random_state)
@@ -74,9 +75,7 @@ def balanced_batch_generator(
         sampler_ = clone(sampler)
     sampler_.fit_resample(X, y)
     if not hasattr(sampler_, "sample_indices_"):
-        raise ValueError(
-            "'sampler' needs to have an attribute " "'sample_indices_'."
-        )
+        raise ValueError("'sampler' needs to have an attribute 'sample_indices_'.")
     indices = sampler_.sample_indices_
     # shuffle the indices since the sampler are packing them by class
     random_state.shuffle(indices)
@@ -84,15 +83,15 @@ def balanced_batch_generator(
     def generator(X, y, sample_weight, indices, batch_size):
         while True:
             for index in range(0, len(indices), batch_size):
-                X_res = _safe_indexing(X, indices[index:index + batch_size])
-                y_res = _safe_indexing(y, indices[index:index + batch_size])
+                X_res = _safe_indexing(X, indices[index : index + batch_size])
+                y_res = _safe_indexing(y, indices[index : index + batch_size])
                 if issparse(X_res) and not keep_sparse:
                     X_res = X_res.toarray()
                 if sample_weight is None:
                     yield X_res, y_res
                 else:
                     sw_res = _safe_indexing(
-                        sample_weight, indices[index:index + batch_size]
+                        sample_weight, indices[index : index + batch_size]
                     )
                     yield X_res, y_res, sw_res
 
