@@ -48,8 +48,9 @@ class ClusterCentroids(BaseUnderSampler):
 
     {random_state}
 
-    estimator : object, default=KMeans()
-        Pass a :class:`sklearn.cluster.KMeans` estimator.
+    estimator : estimator object, default=None
+        Pass a :class:`~sklearn.cluster.KMeans` estimator. By default, it will
+        be a default :class:`~sklearn.cluster.KMeans` estimator.
 
     voting : {{"hard", "soft", "auto"}}, default='auto'
         Voting strategy to generate the new samples:
@@ -68,6 +69,24 @@ class ClusterCentroids(BaseUnderSampler):
       .. deprecated:: 0.7
          `n_jobs` was deprecated in 0.7 and will be removed in 0.9.
 
+    Attributes
+    ----------
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    estimator_ : estimator object
+        The validated estimator created from the `estimator` parameter.
+
+    voting_ : str
+        The validated voting strategy.
+
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     EditedNearestNeighbours : Under-sampling by editing samples.
@@ -118,7 +137,7 @@ ClusterCentroids # doctest: +NORMALIZE_WHITESPACE
         if self.n_jobs != "deprecated":
             warnings.warn(
                 "'n_jobs' was deprecated in 0.7 and will be removed in 0.9",
-                FutureWarning
+                FutureWarning,
             )
         if self.estimator is None:
             self.estimator_ = KMeans(random_state=self.random_state)
@@ -126,17 +145,15 @@ ClusterCentroids # doctest: +NORMALIZE_WHITESPACE
             self.estimator_ = clone(self.estimator)
         else:
             raise ValueError(
-                "`estimator` has to be a KMeans clustering."
-                " Got {} instead.".format(type(self.estimator))
+                f"`estimator` has to be a KMeans clustering."
+                f" Got {type(self.estimator)} instead."
             )
 
     def _generate_sample(self, X, y, centroids, target_class):
         if self.voting_ == "hard":
             nearest_neighbors = NearestNeighbors(n_neighbors=1)
             nearest_neighbors.fit(X, y)
-            indices = nearest_neighbors.kneighbors(
-                centroids, return_distance=False
-            )
+            indices = nearest_neighbors.kneighbors(centroids, return_distance=False)
             X_new = _safe_indexing(X, np.squeeze(indices))
         else:
             if sparse.issparse(X):
@@ -160,23 +177,26 @@ ClusterCentroids # doctest: +NORMALIZE_WHITESPACE
                 self.voting_ = self.voting
             else:
                 raise ValueError(
-                    "'voting' needs to be one of {}. Got {}"
-                    " instead.".format(VOTING_KIND, self.voting)
+                    f"'voting' needs to be one of {VOTING_KIND}. "
+                    f"Got {self.voting} instead."
                 )
 
         X_resampled, y_resampled = [], []
         for target_class in np.unique(y):
+            target_class_indices = np.flatnonzero(y == target_class)
             if target_class in self.sampling_strategy_.keys():
                 n_samples = self.sampling_strategy_[target_class]
                 self.estimator_.set_params(**{"n_clusters": n_samples})
-                self.estimator_.fit(X[y == target_class])
+                self.estimator_.fit(_safe_indexing(X, target_class_indices))
                 X_new, y_new = self._generate_sample(
-                    X, y, self.estimator_.cluster_centers_, target_class
+                    _safe_indexing(X, target_class_indices),
+                    _safe_indexing(y, target_class_indices),
+                    self.estimator_.cluster_centers_,
+                    target_class,
                 )
                 X_resampled.append(X_new)
                 y_resampled.append(y_new)
             else:
-                target_class_indices = np.flatnonzero(y == target_class)
                 X_resampled.append(_safe_indexing(X, target_class_indices))
                 y_resampled.append(_safe_indexing(y, target_class_indices))
 
