@@ -38,12 +38,13 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
 
     {random_state}
 
-    n_neighbors : int or object, default=\
-            KNeighborsClassifier(n_neighbors=1)
+    n_neighbors : int or estimator object, default=None
         If ``int``, size of the neighbourhood to consider to compute the
         nearest neighbors. If object, an estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
-        find the nearest-neighbors.
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        find the nearest-neighbors.  If `None`, a
+        :class:`~sklearn.neighbors.KNeighborsClassifier` with a 1-NN rules will
+        be used.
 
     n_seeds_S : int, default=1
         Number of samples to extract in order to build the set S.
@@ -52,11 +53,24 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    estimator_ : estimator object
+        The validated K-nearest neighbor estimator created from `n_neighbors` parameter.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     EditedNearestNeighbours : Undersample by editing samples.
@@ -80,7 +94,6 @@ class CondensedNearestNeighbour(BaseCleaningSampler):
 
     Examples
     --------
-
     >>> from collections import Counter # doctest: +SKIP
     >>> from sklearn.datasets import fetch_mldata # doctest: +SKIP
     >>> from imblearn.under_sampling import \
@@ -114,9 +127,7 @@ CondensedNearestNeighbour # doctest: +SKIP
     def _validate_estimator(self):
         """Private function to create the NN estimator"""
         if self.n_neighbors is None:
-            self.estimator_ = KNeighborsClassifier(
-                n_neighbors=1, n_jobs=self.n_jobs
-            )
+            self.estimator_ = KNeighborsClassifier(n_neighbors=1, n_jobs=self.n_jobs)
         elif isinstance(self.n_neighbors, int):
             self.estimator_ = KNeighborsClassifier(
                 n_neighbors=self.n_neighbors, n_jobs=self.n_jobs
@@ -125,9 +136,9 @@ CondensedNearestNeighbour # doctest: +SKIP
             self.estimator_ = clone(self.n_neighbors)
         else:
             raise ValueError(
-                "`n_neighbors` has to be a int or an object"
-                " inhereited from KNeighborsClassifier."
-                " Got {} instead.".format(type(self.n_neighbors))
+                f"`n_neighbors` has to be a int or an object"
+                f" inhereited from KNeighborsClassifier."
+                f" Got {type(self.n_neighbors)} instead."
             )
 
     def _fit_resample(self, X, y):
@@ -183,9 +194,7 @@ CondensedNearestNeighbour # doctest: +SKIP
                     # append it in C_x
                     if y_sam != pred_y:
                         # Keep the index for later
-                        idx_maj_sample = np.append(
-                            idx_maj_sample, idx_maj[idx_sam]
-                        )
+                        idx_maj_sample = np.append(idx_maj_sample, idx_maj[idx_sam])
 
                         # Update C
                         C_indices = np.append(C_indices, idx_maj[idx_sam])
@@ -200,9 +209,7 @@ CondensedNearestNeighbour # doctest: +SKIP
                         # well classified elements
                         pred_S_y = self.estimator_.predict(S_x)
                         good_classif_label = np.unique(
-                            np.append(
-                                idx_maj_sample, np.flatnonzero(pred_S_y == S_y)
-                            )
+                            np.append(idx_maj_sample, np.flatnonzero(pred_S_y == S_y))
                         )
 
                 idx_under = np.concatenate((idx_under, idx_maj_sample), axis=0)
