@@ -36,11 +36,11 @@ class NeighbourhoodCleaningRule(BaseCleaningSampler):
     ----------
     {sampling_strategy}
 
-    n_neighbors : int or object, default=3
+    n_neighbors : int or estimator object, default=3
         If ``int``, size of the neighbourhood to consider to compute the
         nearest neighbors. If object, an estimator that inherits from
-        :class:`sklearn.neighbors.base.KNeighborsMixin` that will be used to
-        find the nearest-neighbors.
+        :class:`~sklearn.neighbors.base.KNeighborsMixin` that will be used to
+        find the nearest-neighbors. By default, it will be a 3-NN.
 
     kind_sel : {{"all", "mode"}}, default='all'
         Strategy to use in order to exclude samples in the ENN sampling.
@@ -50,6 +50,9 @@ class NeighbourhoodCleaningRule(BaseCleaningSampler):
         - If ``'mode'``, the majority vote of the neighbours will be used in
           order to exclude a sample.
 
+        The strategy `"all"` will be less conservative than `'mode'`. Thus,
+        more samples will be removed when `kind_sel="all"` generally.
+
     threshold_cleaning : float, default=0.5
         Threshold used to whether consider a class or not during the cleaning
         after applying ENN. A class will be considered during cleaning when:
@@ -63,11 +66,24 @@ class NeighbourhoodCleaningRule(BaseCleaningSampler):
 
     Attributes
     ----------
-    sample_indices_ : ndarray of shape (n_new_samples)
+    sampling_strategy_ : dict
+        Dictionary containing the information to sample the dataset. The keys
+        corresponds to the class labels from which to sample and the values
+        are the number of samples to sample.
+
+    nn_ : estimator object
+        Validated K-nearest Neighbours object created from `n_neighbors` parameter.
+
+    sample_indices_ : ndarray of shape (n_new_samples,)
         Indices of the samples selected.
 
         .. versionadded:: 0.4
 
+    n_features_in_ : int
+        Number of features in the input dataset.
+
+        .. versionadded:: 0.9
+
     See Also
     --------
     EditedNearestNeighbours : Undersample by editing noisy samples.
@@ -86,7 +102,6 @@ class NeighbourhoodCleaningRule(BaseCleaningSampler):
 
     Examples
     --------
-
     >>> from collections import Counter
     >>> from sklearn.datasets import make_classification
     >>> from imblearn.under_sampling import \
@@ -130,8 +145,8 @@ NeighbourhoodCleaningRule # doctest: +NORMALIZE_WHITESPACE
 
         if self.threshold_cleaning > 1 or self.threshold_cleaning < 0:
             raise ValueError(
-                "'threshold_cleaning' is a value between 0 and 1."
-                " Got {} instead.".format(self.threshold_cleaning)
+                f"'threshold_cleaning' is a value between 0 and 1."
+                f" Got {self.threshold_cleaning} instead."
             )
 
     def _fit_resample(self, X, y):
