@@ -3,7 +3,7 @@
 #          Christos Aridas
 # License: MIT
 
-from pytest import raises
+import pytest
 
 from imblearn.base import SamplerMixin
 from imblearn.utils.testing import all_estimators
@@ -23,17 +23,18 @@ def test_all_estimators():
 
     # check that an error is raised when the type is unknown
     type_filter = "rnd"
-    with raises(ValueError, match="Parameter type_filter must be 'sampler'"):
+    with pytest.raises(ValueError, match="Parameter type_filter must be 'sampler'"):
         all_estimators(type_filter=type_filter)
 
 
+@pytest.mark.filterwarnings("ignore:The warns function is deprecated in 0.8")
 def test_warns():
     import warnings
 
     with warns(UserWarning, match=r"must be \d+$"):
         warnings.warn("value must be 42", UserWarning)
 
-    with raises(AssertionError, match="pattern not found"):
+    with pytest.raises(AssertionError, match="pattern not found"):
         with warns(UserWarning, match=r"must be \d+$"):
             warnings.warn("this is not here", UserWarning)
 
@@ -44,7 +45,17 @@ def test_warns():
 
     a, b, c = ("aaa", "bbbbbbbbbb", "cccccccccc")
     expected_msg = r"'{}' pattern not found in \['{}', '{}'\]".format(a, b, c)
-    with raises(AssertionError, match=expected_msg):
+    with pytest.raises(AssertionError, match=expected_msg):
         with warns(UserWarning, match=r"aaa"):
             warnings.warn("bbbbbbbbbb", UserWarning)
             warnings.warn("cccccccccc", UserWarning)
+
+
+# TODO: remove in 0.9
+def test_warns_deprecation():
+    import warnings
+
+    with pytest.warns(None) as record:
+        with warns(UserWarning):
+            warnings.warn("value must be 42")
+    assert "The warns function is deprecated" in str(record[0].message)
